@@ -25,7 +25,6 @@
 
 #include <string.h>
 
-#include <dazzle.h>
 #include <gio/gio.h>
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -86,8 +85,6 @@ static void photos_item_manager_list_model_iface_init (GListModelInterface *ifac
 
 G_DEFINE_TYPE_WITH_CODE (PhotosItemManager, photos_item_manager, PHOTOS_TYPE_BASE_MANAGER,
                          G_IMPLEMENT_INTERFACE (G_TYPE_LIST_MODEL, photos_item_manager_list_model_iface_init));
-DZL_DEFINE_COUNTER (instances, "PhotosItemManager", "Instances", "Number of PhotosItemManager instances")
-
 
 typedef struct _PhotosItemManagerHiddenItem PhotosItemManagerHiddenItem;
 
@@ -1075,8 +1072,6 @@ photos_item_manager_finalize (GObject *object)
   g_free (self->constrain_additions);
 
   G_OBJECT_CLASS (photos_item_manager_parent_class)->finalize (object);
-
-  DZL_COUNTER_DEC (instances);
 }
 
 
@@ -1086,8 +1081,6 @@ photos_item_manager_init (PhotosItemManager *self)
   GEnumClass *window_mode_class; /* TODO: use g_autoptr */
   guint i;
 
-  DZL_COUNTER_INC (instances);
-
   self->collections = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
   self->hidden_items = g_hash_table_new_full (g_str_hash,
                                               g_str_equal,
