@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2021 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -105,6 +105,9 @@ void                      photos_item_manager_set_constraints_for_mode     (Phot
                                                                             gboolean constrain,
                                                                             PhotosWindowMode mode);
 
+void                      photos_item_manager_set_notifier                 (PhotosItemManager *self,
+                                                                            TrackerNotifier *notifier);
+
 void                      photos_item_manager_wait_for_file_async          (PhotosItemManager *self,
                                                                             GFile *file,
                                                                             GCancellable *cancellable,
